@@ -9,6 +9,12 @@
 #include <pango/pangocairo.h>
 #ifdef HAVE_PANGOFT2
 #include <pango/pangofc-fontmap.h>
+#else
+# if !PANGO_VERSION_CHECK (1, 44, 0)
+#  include <hb.h>
+# endif
+# include <ft2build.h>
+# include FT_FREETYPE_H
 #endif
 
 /* Compare two buffers, returning the number of pixels that are
